env_type

Module types

source

Enums

  • EnvType is an enum that represents the environment type. EnvType is derived from the strum crate, which provides the ability to convert the string to the enum.

Traits

  • EnvKey is a trait that represents the environment key.