pub enum EnvType {
Dev,
Test,
Stg,
Prod,
}Expand description
EnvType is an enum that represents the environment type. EnvType is derived from the strum crate, which provides the ability to convert the string to the enum.
Example
use env_type::types::EnvType;
use std::str::FromStr;
let env = EnvType::from_str("d").unwrap();
assert_eq!(EnvType::Dev, env);Variants
Implementations
sourceimpl EnvType
impl EnvType
sourcepub fn from_env() -> Self
pub fn from_env() -> Self
EnvType::from_env is a function that returns the environment type from the environment variable. This is deligated to from_env_key with EnvType as default from env key. The default environment type is Dev.
Example
use env_type::types::EnvType;
use std::str::FromStr;
std::env::set_var("ENV", "Production");
let env = EnvType::from_env();
assert_eq!(EnvType::Prod, env);sourcepub fn from_env_key<T: EnvKey>() -> Self
pub fn from_env_key<T: EnvKey>() -> Self
EnvType::from_env_key is a function that returns the environment type from the environment variable. The default environment type is Dev. /// # Example
use env_type::types::EnvType;
use std::str::FromStr;
std::env::set_var("ENV", "Test");
let env = EnvType::from_env_key::<EnvType>();
assert_eq!(EnvType::Test, env);Trait Implementations
sourceimpl EnvKey for EnvType
impl EnvKey for EnvType
EnvType is an implementation of the EnvKey trait. The default environment key is “ENV”.
impl Copy for EnvType
impl Eq for EnvType
impl StructuralPartialEq for EnvType